PhysicsWorld

Struct PhysicsWorld 

pub struct PhysicsWorld {
Show 14 fields pub gravity: Vector3<f32>, pub rigid_body_set: RigidBodySet, pub collider_set: ColliderSet, pub integration_parameters: IntegrationParameters, pub island_manager: IslandManager, pub broad_phase: BroadPhase, pub narrow_phase: NarrowPhase, pub impulse_joint_set: ImpulseJointSet, pub multibody_joint_set: MultibodyJointSet, pub ccd_solver: CCDSolver, pub query_pipeline: QueryPipeline, pub named_rigid_bodies: NamedHandleMap<RigidBodyHandle>, pub named_sensors: NamedHandleMap<ColliderHandle>, pub pipeline: PhysicsPipeline, /* private fields */
}
The physics management structure. This is a thin wrapper around the Rapier physics engine with additional utilities.

Fields

gravity: Vector3<f32>rigid_body_set: RigidBodySetcollider_set: ColliderSetintegration_parameters: IntegrationParametersisland_manager: IslandManagerbroad_phase: BroadPhasenarrow_phase: NarrowPhaseimpulse_joint_set: ImpulseJointSetmultibody_joint_set: MultibodyJointSetccd_solver: CCDSolverquery_pipeline: QueryPipelinenamed_rigid_bodies: NamedHandleMap<RigidBodyHandle>named_sensors: NamedHandleMap<ColliderHandle>pipeline: PhysicsPipeline

Implementations

Source

impl PhysicsWorld

pub fn remove_body(&mut self, body_handle: RigidBodyHandle) -> Option<RigidBody>

Remove a RigidBody from the physics world using its handle.

pub fn load_from_gltf( &mut self, gltf: &Gltf, parent_transform: Option<Transform3<f32>>, ) -> Result<(), PhysicsWorldInitError>

Load physics-enabled objects from a Perigee-enabled glTF into the physics world.

Note: Nodes that are children of others will be ignored.

pub fn listen_to_collider<L: ColliderEventListener + 'static>( &mut self, handle: ColliderHandle, listener: L, )

pub fn rekey_listeners( &mut self, old_handle: ColliderHandle, new_handle: ColliderHandle, )

pub fn step(&mut self, delta_seconds: f32)

Step the physics simulation by the provided number of seconds.

pub unsafe fn get_body_handle(body: &RigidBody) -> RigidBodyHandle

Recover the handle from a RigidBody using its user_data field.

pub unsafe fn store_handle_in_body( handle: &RigidBodyHandle, body: &mut RigidBody, )

Store the parts of the RigidBody’s handle in its user_data field.